==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm
 */
@JsonPropertyOrder({ AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm.JSON_PROPERTY_ID })
@JsonTypeName("AuthenticatorKeyCustomApp_allOf_provider_configuration_fcm")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm() {
    }

    public AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm id(String id) {

        this.id = id;
        return this;
    }

    /**
     * ID of the FCM (Firebase Cloud Messaging Service)
     * [configurations](https://developer.okta.com/docs/reference/api/push-providers/)
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "ID of the FCM (Firebase Cloud Messaging Service) [configurations](https://developer.okta.com/docs/reference/api/push-providers/)")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setId(String id) {
        this.id = id;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm authenticatorKeyCustomAppAllOfProviderConfigurationFcm = (AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm) o;
        return Objects.equals(this.id, authenticatorKeyCustomAppAllOfProviderConfigurationFcm.id);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm
 */
@JsonPropertyOrder({ AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm.JSON_PROPERTY_ID })
@JsonTypeName("AuthenticatorKeyCustomApp_allOf_provider_configuration_fcm")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm() {
    }

    public AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm id(String id) {

        this.id = id;
        return this;
    }

    /**
     * ID of the FCM (Firebase Cloud Messaging Service)
     * [configurations](https://developer.okta.com/docs/reference/api/push-providers/)
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "ID of the FCM (Firebase Cloud Messaging Service) [configurations](https://developer.okta.com/docs/reference/api/push-providers/)")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setId(String id) {
        this.id = id;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm authenticatorKeyCustomAppAllOfProviderConfigurationFcm = (AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm) o;
        return Objects.equals(this.id, authenticatorKeyCustomAppAllOfProviderConfigurationFcm.id);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorKeyCustomAppAllOfProviderConfigurationFcm {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
